@@ -13,7 +13,9 @@ use Config;
 sub build_binaries {
   my ($self, $build_out, $srcdir) = @_;
 
+  print "Checking available libraries/headers...\n";
   my %has;
+  
   $has{gtk}     = `pkg-config --modversion gtk+-2.0 2>/dev/null` ? 1 : 0;	#iupgtk
   $has{gdk}     = `pkg-config --modversion gdk-2.0 2>/dev/null` ? 1 : 0;	#cdgdk
   $has{cairo}   = `pkg-config --modversion cairo 2>/dev/null` ? 1 : 0; 		#cdcairo
@@ -21,8 +23,11 @@ sub build_binaries {
 
   $has{l_cairo} = $self->check_lib( [] , `pkg-config --cflags cairo 2>/dev/null`, `pkg-config --libs cairo 2>/dev/null`);
   $has{l_pango} = $self->check_lib( [] , `pkg-config --cflags pango 2>/dev/null`, `pkg-config --libs pango 2>/dev/null`);
+  $has{l_pangox}= $self->check_lib( [] , `pkg-config --cflags pangox 2>/dev/null`, `pkg-config --libs pangox 2>/dev/null`);
   $has{l_gtk}   = $self->check_lib( [] , `pkg-config --cflags gtk+-2.0 2>/dev/null`, `pkg-config --libs gtk+-2.0 2>/dev/null`);
+  $has{l_gtkx11}= $self->check_lib( [] , `pkg-config --cflags gtk+-x11-2.0 2>/dev/null`, `pkg-config --libs gtk+-x11-2.0 2>/dev/null`);
   $has{l_gdk}   = $self->check_lib( [] , `pkg-config --cflags gdk-2.0 2>/dev/null`, `pkg-config --libs gdk-2.0 2>/dev/null`);
+  $has{l_gdkx11}= $self->check_lib( [] , `pkg-config --cflags gdk-x11-2.0 2>/dev/null`, `pkg-config --libs gdk-x11-2.0 2>/dev/null`);
   $has{l_Xp}    = $self->check_lib( 'Xp' );
   $has{l_Xt}    = $self->check_lib( 'Xt' );
   $has{l_Xm}    = $self->check_lib( 'Xm' );
@@ -44,6 +49,8 @@ sub build_binaries {
   $has{ecw}     = $self->check_header('NCSECWClient.h');	#im_format_ecw = ECW (Enhanced Compression Wavelet) format
   $has{XxXxX}   = $self->check_header('XxXxX/XxXxX.h');   	#non existing header
 
+  print "Has: $has{$_} - $_\n" foreach (sort keys %has);
+
   #possible targets: im im_process im_jp2 im_fftw im_capture im_avi im_wmv im_fftw3 im_ecw
   my @imtargets = qw[im im_process im_jp2 im_fftw];
 
@@ -111,8 +118,9 @@ sub build_via_tecmake {
   $srcdir ||= 'src';
   my $prefixdir   = rel2abs($build_out);
   my $make        = $self->get_make;
-  my @makesysinfo = qw/-f tecmake.mak sysinfo MAKENAME= USE_NODEPEND=Yes/;
+  my $makesysinfo = "$make -f tecmake.mak sysinfo MAKENAME= USE_NODEPEND=Yes";
   my @makeopts    = @{$mopts};
+  my ($im_si, $cd_si, $iup_si);
 
   # save it for future use in ConfigData
   $self->config_data('build_prefix', $prefixdir);
@@ -128,7 +136,8 @@ sub build_via_tecmake {
   if(-d "$srcdir/im/src") {
     print "Gonna build 'im'\n";
     chdir "$srcdir/im/src";
-    $self->do_system($make, @makesysinfo); ## maybe store into configdata xxx
+    ($im_si =`$makesysinfo 2>&1`) =~ s/[\n\r]*$//;
+    print "Tecmake sysinfo:\n$im_si\n";
     foreach my $t (@{$imtgs}) {
       my @cmd = ($make, $t, @makeopts);
       print "Running make $t ...\n(cmd: ".join(' ',@cmd).")\n";
@@ -143,7 +152,8 @@ sub build_via_tecmake {
   if (-d "$srcdir/cd/src") {
     print "Gonna build 'cd'\n";
     chdir "$srcdir/cd/src";
-    $self->do_system($make, @makesysinfo); ## maybe store into configdata xxx
+    ($cd_si =`$makesysinfo 2>&1`) =~ s/[\n\r]*$//;
+    print "Tecmake sysinfo:\n$cd_si\n";
     foreach my $t (@{$cdtgs}) {
       my @cmd = ($make, $t, @makeopts);
       print "Running make $t ...\n(cmd: ".join(' ',@cmd).")\n";
@@ -158,7 +168,8 @@ sub build_via_tecmake {
   if (-d "$srcdir/iup") {
     print "Gonna build 'iup'\n";
     chdir "$srcdir/iup";
-    $self->do_system($make, @makesysinfo); ## maybe store into configdata xxx
+    ($iup_si =`$makesysinfo 2>&1`) =~ s/[\n\r]*$//;
+    print "Tecmake sysinfo:\n$iup_si\n";
     foreach my $t (@{$iuptgs}) {
       my @cmd = ($make, $t, @makeopts);
       print "Running make $t ...\n(cmd: ".join(' ',@cmd).")\n";
@@ -170,7 +181,13 @@ sub build_via_tecmake {
     chdir $self->base_dir();
   }
 
+  unless ($done{iup} && $done{iupim} && $done{iupcd}) {
+    print "Done: $done{$_} - $_\n" foreach (sort keys %done);
+    die "###MAKE FAILED### iup=$done{iup} iupim=$done{iupim} iupcd=$done{iupcd}";
+  }
+
   $self->config_data('debug_done', \%done);
+  $self->config_data('debug_si', { im => $im_si, cd => $cd_si, iup => $iup_si } );
   return 1;
 }
 
